<h1 align="center">
  phidata
</h1>
<p align="center">
    <em>Building Blocks for Data Engineering</em>
</p>

<p align="center">
<a href="https://python.org/pypi/phidata" target="_blank">
    <img src="https://img.shields.io/pypi/v/phidata?color=blue&label=version" alt="version">
</a>
<a href="https://github.com/phidatahq/phidata" target="_blank">
    <img src="https://img.shields.io/badge/python->=3.7-blue" alt="pythonversion">
</a>
<a href="https://github.com/phidatahq/phidata" target="_blank">
    <img src="https://pepy.tech/badge/phidata" alt="downloads">
</a>
<a href="https://github.com/phidatahq/phidata/actions/workflows/build.yml" target="_blank">
    <img src="https://github.com/phidatahq/phidata/actions/workflows/build.yml/badge.svg" alt="build-status">
</a>

[//]: # (<a href="https://github.com/phidatahq/phidata/actions/workflows/test.yml" target="_blank">)

[//]: # (    <img src="https://github.com/phidatahq/phidata/actions/workflows/test.yml/badge.svg" alt="test-status">)

[//]: # (</a>)

</p>

---

Phidata is a framework for building Data Applications using open source software (OSS). We believe that large Data, ML and AI products can easily be built using OSS.

### How it works

- Phidata converts infrastructure and tools into python objects (building blocks).
- These objects are put together to build Data Applications as Code.
- Download a pre-built Data App using `phi ws create`
- Run a local dev environment using `phi ws up dev:docker`
- Customize the app to your use case and make it your own.
- Deploy to production using `phi ws up prd:aws`
- Stop workspace using `phi ws down`

### More Information:

- **Documentation**: <a href="https://docs.phidata.com" target="_blank">https://docs.phidata.com</a>
- **Questions:** Come chat with us on <a href="https://discord.gg/4MtYHHrgA8" target="_blank">Discord</a>
- **Email**: <a href="mailto:help@phidata.com" target="_blank">help@phidata.com</a>
